/* cfgfile.h -- Parsing a configuration file into data structures. */
/* $Id: cfgfile.h,v 0.3 1997/11/01 03:33:17 eagle Exp $ */

#ifndef __h_cfgfile__
#define __h_cfgfile__

/***************************************************************************
* Includes
***************************************************************************/

#include <sys/types.h>          /* uid_t, gid_t, mode_t */

/***************************************************************************
* Data structures
***************************************************************************/

/* A linked list of archive locations and the number of old logs to save (if
   any) for a log. */

struct archive {
  char *path;                   /* Path to the archive name. */
  int count;                    /* Number of old logs to save. */

  struct archive *next;
};


/* A linked list of logs to rotate, along with the directories to move them
   into and the mode and ownership to give the new log. */

struct log {
  char *name;                   /* Name of the local logfile. */
  char *path;                   /* Path to the local logfile. */
  char *tmppath;                /* Temporary local path for rotation. */
  struct archive *archives;     /* Locations to archive a copy of it. */
  int rotate;                   /* Whether to rotate the log. */
  uid_t owner;                  /* Owner of the new logfile. */
  gid_t group;                  /* Group of the new logfile. */
  mode_t mode;                  /* Permissions for the new logfile. */

  struct log *next;
};


/* A command (either a "run" or a "hup" command, depending on which fields
   are filled in).  It's a "hup" command if there's a pidfile and a "run"
   command if arguments is filled in. */

struct command {
  char *pidfile;                /* PID file for a hup command. */
  char **argv;                  /* NULL-terminated array of args for run. */
};


/* A linked list of classes of logs.  Each class stores the stop and restart
   commands for the server and a pointer to a list of logs to rotate. */

struct class {
  char *name;                   /* Name of the log class. */
  struct command *stop;         /* Command to stop the server. */
  struct command *restart;      /* Command to restart the server. */
  struct log *logs;             /* List of logs to rotate. */

  struct class *next;
};

/***************************************************************************
* Prototypes
***************************************************************************/

/* Read in a configuration file and return a list of log classes. */
extern struct class *read_config (char *filename);

/**************************************************************************/

#endif /* __h_cfgfile__ */
